#
# spec file for package ccache
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ccache
Version:        3.2.3
Release:        6.5
Summary:        A Fast C/C++ Compiler Cache
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Url:            http://ccache.samba.org/
Source0:        http://samba.org/ftp/%{name}/%{name}-%{version}.tar.xz
Source1:        http://samba.org/ftp/%{name}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  xz
BuildRequires:  zlib-devel
Provides:       distcc:/usr/bin/ccache
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ccache is a compiler cache. It speeds up recompilation by caching the result of
previous compilations and detecting when the same compilation is being done
again. Supported languages are C, C++, Objective-C and Objective-C++.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} %{?_smp_mflags}

# create the compat symlinks into /usr/libdir/ccache
mkdir -p %{buildroot}/%{_libdir}/%{name}
cd %{buildroot}/%{_libdir}/%{name}
ln -sf ../../bin/%{name} gcc
ln -sf ../../bin/%{name} g++

%check
%ifarch i586
# On i586 use only quick minimal testsuite, full one fails
# (https://bugzilla.samba.org/show_bug.cgi?id=11109)
# We disable the full test-suite on x86-64 too because
# "readonly" testsuite takes forever on OBS.
make quicktest %{?_smp_mflags}
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS.* GPL-3.0.txt LICENSE.* MANUAL.* NEWS.* README.*
%doc %{_mandir}/man1/%{name}.1%{ext_man}
%{_bindir}/%{name}
%{_libdir}/%{name}

%changelog
* Sat Aug 22 2015 astieger@suse.com
- update to 3.2.3:
  * Added support for compiler option -gsplit-dwarf.
  * Support external zlib in nonstandard directory.
  * Avoid calling exit() inside an exit handler.
  * Let exit handler terminate properly.
  * Bail out on compiler option --save-temps in addition to
  - save-temps.
  * Only log "Disabling direct mode" once when failing to read
    potential include files.
* Fri May 22 2015 mpluskal@suse.com
- Update to 3.2.2
  * Added support for `CCACHE_COMPILERCHECK=string:<value>`. This
    is a faster alternative to `CCACHE_COMPILERCHECK=<command>` if
    the command's output can be precalculated by the build system.
  * Add support for caching code coverage results (compiling for
    gcov).
  * Fixed bug which could result in false cache hits when source
    code contains `'"'` followed by `" /*"` or `" //"` (with
    variations).
  * Made hash of cached result created with and without
    `CCACHE_CPP2` different. This makes it possible to rebuild
    with `CCACHE_CPP2` set without having to clear the cache to
    get new results.
  * Don't try to reset a non-existing stats file. This avoids
    ``No such file or directory'' messages in the ccache log when
    the cache directory doesn't exist.
  * Fixed a bug where ccache deleted clang diagnostics after
    compiler failures.
  * Avoid performing an unnecessary copy of the object file on a
    cache miss.
  * Bail out on too hard compiler option `-fmodules`.
  * Bail out on too hard compiler option `-fplugin=libcc1plugin`
    (interaction with GDB).
  * Fixed build error when compiling ccache with recent clang
    versions.
  * Removed signal-unsafe code from signal handler.
  * Corrected logic for when to output cached stderr.
  * Wipe the whole cached result on failure retrieving a cached
    file.
  * Fixed build error when compiling ccache with recent clang
    versions.
* Fri May 15 2015 mvyskocil@opensuse.org
- Add the compat symlinks for gcc/g++ to libdir, so prepending
  libdir to PATH enabled ccache by default
* Fri Feb 20 2015 mpluskal@suse.com
- Add gpg signature
- Remove ccache-gcc48.patch and xclang.patch (both are already
  present in current release)
- On i586, use only small testsuite (quicktest) full testsuite
  fails (https://bugzilla.samba.org/show_bug.cgi?id=11109)
- Update to 3.2.1:
  * Added support for configuring ccache via one or several
    configuration files instead of via environment variables.
    Environment variables still have priority but are no longer
    the recommended way of customizing ccache behavior. See the
    manual for more information.
  * Added support for compiler error/warning messages with color.
  * Made creation of temporary directories and cache directories
    smarter to avoid unnecessary stat calls.
  * Improved efficiency of the algorithm that scans for
    __DATE_ and __TIME__ tokens in the hashed source code.
  * Added support for several binaries (separated by space) in
    CCACHE_PREFIX.
  * The -c option is no longer passed to the preprocessor.
    This fixes problems with clang and Solaris’s C++ compiler.
  * ccache no longer passes preprocessor options like -D and -I to
    the compiler when compiling preprocessed output. This fixes
    warnings emitted by clang.
  * Compiler options -fprofile-generate, -fprofile-arcs,
  - fprofile-use and -fbranch-probabilities are now handled
    without bailing.
  * Added support for clang’s --serialize-diagnostic option,
    storing the diagnostic file (.dia) in the cache.
  * Added support for precompiled headers when using clang.
  * Changed the -x language option to use the new objective C
    standard for GCC and clang.
  * On a cache miss, ccache now instructs the compiler to create
    the object file at the real destination and then copies the
    file into the cache instead of the other way around. This is
    needed to support compiler options like -fprofile-arcs
    and --serialize-diagnostics.
  * ccache now checks that included files' ctimes aren’t too new.
    This check can be turned off by adding include_file_ctime
    to the “ccache sloppinessâhe filename part of options
    like -Wp,-MDfilename is no longer included in the hash
    since the filename doesn’t have any bearing on the result.
  * Added a “read-only directâefault cache size is now 5 GB
    (was previously 1 GiB).
  * Added support for @file and -@file arguments (reading options
    from a file).
  * Bail out on too hard compiler option -Wp,-P.
  * Optimized MD4 calculation code on little-endian systems.
  * Various improvements and fixes on win32.
  * Improved logging to the ccache log file.
  * Added --dump-manifest command-line option for debugging purposes.
  * Added --with-bundled-zlib configure option.
  * Upgraded bundled zlib to version 1.2.8.
  * Improved dev.mk to be more platform independent.
  * Made the test suite work with clang and gcc-llvm on OS X.
  * Various other improvements of the test suite.
* Tue Jun 25 2013 pgajdos@suse.com
- fixed build with gcc 4.8
  * ccache-gcc48.patch
* Sat Feb 23 2013 asterios.dramis@gmail.com
- Update to 3.1.9:
  - The EAGAIN signal is now handled correctly when emitting cached stderr
    output. This fixes a problem triggered by large error outputs from the
    compiler.
  - Subdirectories in the cache are no longer created in read-only mode.
  - Fixed so that ccache's log file descriptor is not made available to the
    compiler.
  - Improved error reporting when failing to create temporary stdout/stderr
    files when executing the compiler.
  - Disappearing temporary stdout/stderr files are now handled gracefully.
  - Fixed test suite to work on ecryptfs.
* Fri Jan  4 2013 llunak@suse.com
- Add xclang.patch: support -Xclang option
* Fri Nov  9 2012 idonmez@suse.com
- Implement %%check
- Don't install INSTALL.* files
* Sat Aug 11 2012 puzel@suse.com
- update to ccache-3.1.8
  - Made paths to dependency files relative in order to increase
    cache hits.
  - Added work-around to make ccache work with buggy GCC 4.1 when
    creating a pre-compiled header.
  - Clang plugins are now hashed to catch plugin upgrades.
  - Fixed crash when the current working directory has been
    removed.
  - Fixed crash when stderr is closed.
  - Corrected a corner case when parsing backslash escapes in
    string literals.
  - Paths are now correctly canonicalized when computing paths
    relative to the base directory.
  - Made git version macro work when compiling outside of the
    source directory.
  - Fixed `static_assert` macro definition clash with GCC 4.7.
* Mon Jan  9 2012 puzel@suse.com
- update to ccache-3.1.7
  - Non-writable `CCACHE_DIR` is now handled gracefully when
    `CCACHE_READONLY` is set.
  - Made failure to create files (typically due to bad directory
    permissions) in the cache directory fatal. Previously, such
    failures were silently and erroneously flagged as "compiler
    produced stdout".
  - Both the `-specs=file` and `--specs=file` forms are now
    recognized.
  - Added recognition and hashing of GCC plugins specified with
    `-fplugin=file`.
  - `CCACHE_COMPILERCHECK` now also determines how to hash explicit
    specs files (`-specs=file`).
  - Added `CPATH`, `C_INCLUDE_PATH` and similar environment
    variables to the hash to avoid false cache hits when such
    variables have changed.
  - Corrected log message when unify mode is enabled.
  - Reverted the GCC bug compatibility introduced in ccache 3.1.5
    for `-MT`/`-MQ` options with concatenated arguments. (The bug
    is fixed in recent GCC versions.)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Sun Aug 21 2011 asterios.dramis@gmail.com
- update to ccache-3.1.6
  - Rewrite argument to --sysroot if CCACHE_BASEDIR is used.
  - Don't crash if getcwd() fails.
  - Fixed alignment of "called for preprocessing" counter.
* Mon Jun  6 2011 puzel@novell.com
- update to ccache-3.1.5
  - Added a new statistics counter named ``called for
    preprocessing''.
  - The original command line is now logged to the file specified
    with `CCACHE_LOGFILE`.
  - Improved error logging when system calls fail.
  - Added support for rewriting absolute paths in
    `-F`/`-iframework` GCC options.
  - Improved order of statistics counters in `ccache -s` output.
  - The `-MF`/`-MT`/`-MQ` options with concatenated argument are
    now handled correctly when they are last on the commandline.
  - ccache is now bug compatible with GCC for the `-MT`/`-MQ`
    options with concatenated arguments.
  - Fixed a minor memory leak.
  - Systems that lack (and don't need to be linked with) libm are
    now supported.
* Wed Feb 16 2011 asterios.dramis@gmail.com
- update to ccache-3.1.4
  - Made a work-around for a bug in gzputc() in zlib 1.2.5.
  - Corrupt manifest files are now removed so that they won't block direct
    mode hits.
  - ccache now copes with file systems that don't know about symbolic links.
  - The file handle in now correctly closed on write error when trying to
    create a cache dir tag.
- Spec file updates:
  - Changes based on rpmdevtools templates and spec-cleaner run.
  - Updated Summary: and %%description.
  - Made it compile with external zlib instead of the bundled copy.
  - Added also the html files in the %%doc section.
* Mon Nov 29 2010 puzel@novell.com
- update to ccache-3.1.3
  - The -MFarg, -MTarg and -MQarg compiler options (i.e, without
    space between option and argument) are now handled correctly.
* Mon Nov 22 2010 puzel@novell.com
- update to ccache-3.1.2
  - bail out on too hard compiler options '-fdump-*'
  - NULL return values from malloc/calloc of zero bytes are now
    handled correctly
  - improved documentation on which information is included in the
    hash sum
  - made the 'too new header file' test case work on file systems
    with unsynchronized clocks
  - the test suite now also works on systems that lack a /dev/zero
* Mon Nov  8 2010 puzel@novell.com
- update to ccache-3.1.1
  - ccache now falls back to preprocessor mode when a non-regular
    include file (device, socket, etc) has been detected so that
    potential hanging due to blocking reads is avoided.
  - CRC errors are now detected when decompressing compressed files
    in the cache.
  - Fixed potential object file corruption race on NFS.
  - Minor documentation corrections.
  - Fixed configure detection of ar.
  - ccache development version (set by dev.mk) now works with gits
    whose `describe` command doesn't understand `--dirty`.
* Fri Sep 17 2010 puzel@novell.com
- update to ccache-3.1
  - features:
  - Added support for hashing the output of a custom command
    (e.g. `$compiler --version`) to identify the compiler
    instead of stat-ing or hashing the compiler binary.
  - Added support for caching compilations that use precompiled
    headers.
  - Locking of the files containing statistics counters is now
    done using symlinks instead of POSIX locks.
  - Manifest files are now updated without the need of taking
    locks.
  - Added `.cp` and `.CP` as known C++ suffixes.
  - Improved logging.
  - bugfixes:
  - Non-fatal error messages are now never printed to stderr but
    logged instead.
  - Fixed a bug affecting failing commands when `--ccache-skip` is
    used.
  - Made `--ccache-skip` work for all options.
  - EINTR is now handled correctly.
* Fri Jul 16 2010 puzel@novell.com
- update to ccache-3.0.1
  - bugfixes:
  - The statistics counter ``called for link'' is now correctly
    updated when linking with a single object file.
  - Fixed a problem with out-of-source builds.
* Mon Jul 12 2010 puzel@novell.com
- update to ccache-3.0
  - notable changes:
  - The way the hashes are calculated has changed, so you won't get
  cache hits for compilation results stored by older ccache
  versions. Because of this, you might as well clear the old
  cache directory with `ccache --clear` if you want, unless you
  plan to keep using an older ccache version.
  - ccache now has a ``direct mode'' where it computes a hash of
  the source code (including all included files) and compiler
  options without running the preprocessor. By not running the
  preprocessor, CPU usage is reduced; the speed is somewhere
  between 1 and 5 times that of ccache running in traditional
  mode, depending on the circumstances. The speedup will be
  higher when I/O is fast (e.g., when files are in the disk
  cache).  The direct mode can be disabled by setting
  +CCACHE_NODIRECT+.
  - Support has been added for rewriting absolute paths to relative
  paths when hashing, in order to increase cache hit rate when
  building the same source code in different directories even
  when compiling with `-g` and when using absolute include
  directory paths. This is done by setting the `CCACHE_BASEDIR`
  environment variable to an absolute path that specifies which
  paths to rewrite.
  - Object files are now optionally stored compressed in the cache.
  The runtime cost is negligible, and more files will fit in the
  ccache directory and in the disk cache. Set `CCACHE_COMPRESS`
  to enable object file compression. Note that you can't use
  compression in combination with the hard link feature.
  - A `CCACHE_COMPILERCHECK` option has been added. This option
  tells ccache what compiler-identifying information to hash to
  ensure that results retrieved from the cache are accurate.
  Possible values are: none (don't hash anything), mtime (hash
  the compiler's mtime and size) and content (hash the content of
  the compiler binary). The default is mtime.
- see /usr/share/doc/packages/ccache/NEWS.txt for complete
  release notes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 29 2005 dmueller@suse.de
- add norootforbuild
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Thu Oct 21 2004 ltinkl@suse.cz
- update to version 2.4
* Mon Sep 29 2003 ltinkl@suse.cz
- update to version 2.3
* Wed Jul  9 2003 ltinkl@suse.cz
- updated sources to version 2.2
* Fri Mar 28 2003 vbobek@suse.cz
- provides binary from older distcc package [#25806]
* Mon Feb 10 2003 vbobek@suse.cz
- initial suse release 2.1.1
